==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebColumnPipeArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFieldPipeArgsDescriptionMetadata } from "./WebFieldPipeArgsDescriptionMetadata";
import { WebColumnPipeArgsDescription } from "./WebColumnPipeArgsDescription";
/**
 * @hidden
 */
var WebColumnPipeArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnPipeArgsDescriptionMetadata, _super);
    function WebColumnPipeArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnPipeArgsDescriptionMetadata.b = function (a) {
        if (WebColumnPipeArgsDescriptionMetadata.a == null) {
            WebColumnPipeArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnPipeArgsDescriptionMetadata.c(WebColumnPipeArgsDescriptionMetadata.a);
        }
        if (a.j(WebColumnPipeArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebColumnPipeArgsDescriptionMetadata.a);
    };
    WebColumnPipeArgsDescriptionMetadata.c = function (a) {
        WebFieldPipeArgsDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnPipeArgs");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
    };
    WebColumnPipeArgsDescriptionMetadata.d = function (a) {
        WebColumnPipeArgsDescriptionMetadata.b(a);
        a.aa("WebColumnPipeArgs", function () { return new WebColumnPipeArgsDescription(); });
        a.z("WebColumnPipeArgs", WebColumnPipeArgsDescriptionMetadata.a);
    };
    WebColumnPipeArgsDescriptionMetadata.$t = markType(WebColumnPipeArgsDescriptionMetadata, 'WebColumnPipeArgsDescriptionMetadata');
    WebColumnPipeArgsDescriptionMetadata.a = null;
    return WebColumnPipeArgsDescriptionMetadata;
}(Base));
export { WebColumnPipeArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebColumnPipeArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFieldPipeArgsDescriptionMetadata } from "./WebFieldPipeArgsDescriptionMetadata";
import { WebColumnPipeArgsDescription } from "./WebColumnPipeArgsDescription";
/**
 * @hidden
 */
var WebColumnPipeArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnPipeArgsDescriptionMetadata, _super);
    function WebColumnPipeArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnPipeArgsDescriptionMetadata.b = function (a) {
        if (WebColumnPipeArgsDescriptionMetadata.a == null) {
            WebColumnPipeArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnPipeArgsDescriptionMetadata.c(WebColumnPipeArgsDescriptionMetadata.a);
        }
        if (a.k(WebColumnPipeArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebColumnPipeArgsDescriptionMetadata.a);
    };
    WebColumnPipeArgsDescriptionMetadata.c = function (a) {
        WebFieldPipeArgsDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnPipeArgs");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebColumnPipeArgsDescriptionMetadata.d = function (a) {
        WebColumnPipeArgsDescriptionMetadata.b(a);
        a.ac("WebColumnPipeArgs", function () { return new WebColumnPipeArgsDescription(); });
        a.ab("WebColumnPipeArgs", WebColumnPipeArgsDescriptionMetadata.a);
    };
    WebColumnPipeArgsDescriptionMetadata.$t = markType(WebColumnPipeArgsDescriptionMetadata, 'WebColumnPipeArgsDescriptionMetadata');
    WebColumnPipeArgsDescriptionMetadata.a = null;
    return WebColumnPipeArgsDescriptionMetadata;
}(Base));
export { WebColumnPipeArgsDescriptionMetadata };
